@@ -117,7 +117,7 @@ extern struct ifqueue   ipintrq;		/* ip packet input queue */
 /* END OF INCLUDES */
 
 #if !defined(lint)
-static const char rcsid[] = "@(#)$Id: ip_auth.c,v 2.73.2.16 2006/10/26 02:52:29 darrenr Exp $";
+static const char rcsid[] = "@(#)$Id: ip_auth.c,v 2.73.2.18 2006/12/16 17:12:56 darrenr Exp $";
 #endif
 
 
@@ -456,7 +456,9 @@ void *ctx;
 		i = fr_authflush();
 		RWLOCK_EXIT(&ipf_auth);
 		SPL_X(s);
-		error = copyoutptr((char *)&i, data, sizeof(i));
+		error = BCOPYOUT((char *)&i, data, sizeof(i));
+		if (error != 0)
+			error = EFAULT;
 		break;
 
 	case SIOCAUTHW:
@@ -931,7 +933,7 @@ fr_authioctlloop:
 	READ_ENTER(&ipf_global);
 	if (error == 0)
 		goto fr_authioctlloop;
-	return 0;
+	return error;
 }
 
 
