@@ -37,7 +37,7 @@
  *   o The enclosed hack of STREAMS support is pretty sick and most likely
  *     broken.
  *
- *	$Id: ip_rpcb_pxy.c,v 2.25.2.4 2006/07/14 06:12:18 darrenr Exp $
+ *	$Id: ip_rpcb_pxy.c,v 2.25.2.5 2006/12/18 05:00:57 darrenr Exp $
  */
 
 #define	IPF_RPCB_PROXY
@@ -1156,6 +1156,8 @@ ippr_rpcb_getnat(fin, nat, proto, port)
 
 	/* Generate dummy fr_info */
 	bcopy((char *)fin, (char *)&fi, sizeof(fi));
+	fi.fin_state = NULL;
+	fi.fin_nat = NULL;
 	fi.fin_out = 0;
 	fi.fin_src = fin->fin_dst;
 	fi.fin_dst = nat->nat_outip;
