@@ -18,7 +18,11 @@ typedef	unsigned long	ulong;
 #include	<sys/types.h>
 #include	<sys/stream.h>
 #include	<sys/stropts.h>
-#include	<sys/dlpi.h>
+#ifdef __osf__
+# include	<sys/dlpihdr.h>
+#else
+# include	<sys/dlpi.h>
+#endif
 #include	<sys/signal.h>
 #include	<stdio.h>
 #include	<string.h>
@@ -35,6 +39,7 @@ char	*dlstyle();
 char	*dlmactype();
 
 
+void
 dlinforeq(fd)
 int	fd;
 {
@@ -54,6 +59,7 @@ int	fd;
 		syserr("dlinforeq:  putmsg");
 }
 
+void
 dlinfoack(fd, bufp)
 int	fd;
 char	*bufp;
@@ -82,6 +88,7 @@ char	*bufp;
 		err("dlinfoack:  short response ctl.len:  %d", ctl.len);
 }
 
+void
 dlattachreq(fd, ppa)
 int	fd;
 u_long	ppa;
@@ -103,6 +110,7 @@ u_long	ppa;
 		syserr("dlattachreq:  putmsg");
 }
 
+void
 dlenabmultireq(fd, addr, length)
 int	fd;
 char	*addr;
@@ -131,6 +139,7 @@ int	length;
 		syserr("dlenabmultireq:  putmsg");
 }
 
+void
 dldisabmultireq(fd, addr, length)
 int	fd;
 char	*addr;
@@ -159,6 +168,7 @@ int	length;
 		syserr("dldisabmultireq:  putmsg");
 }
 
+void
 dlpromisconreq(fd, level)
 int	fd;
 u_long	level;
@@ -181,6 +191,7 @@ u_long	level;
 
 }
 
+void
 dlpromiscoff(fd, level)
 int	fd;
 u_long	level;
@@ -202,6 +213,7 @@ u_long	level;
 		syserr("dlpromiscoff:  putmsg");
 }
 
+void
 dlphysaddrreq(fd, addrtype)
 int	fd;
 u_long	addrtype;
@@ -223,6 +235,7 @@ u_long	addrtype;
 		syserr("dlphysaddrreq:  putmsg");
 }
 
+void
 dlsetphysaddrreq(fd, addr, length)
 int	fd;
 char	*addr;
@@ -251,6 +264,7 @@ int	length;
 		syserr("dlsetphysaddrreq:  putmsg");
 }
 
+void
 dldetachreq(fd)
 int	fd;
 {
@@ -270,6 +284,7 @@ int	fd;
 		syserr("dldetachreq:  putmsg");
 }
 
+void
 dlbindreq(fd, sap, max_conind, service_mode, conn_mgmt, xidtest)
 int	fd;
 u_long	sap;
@@ -299,6 +314,7 @@ u_long	xidtest;
 		syserr("dlbindreq:  putmsg");
 }
 
+void
 dlunitdatareq(fd, addrp, addrlen, minpri, maxpri, datap, datalen)
 int	fd;
 u_char	*addrp;
@@ -333,6 +349,7 @@ int	datalen;
 		syserr("dlunitdatareq:  putmsg");
 }
 
+void
 dlunbindreq(fd)
 int	fd;
 {
@@ -352,6 +369,7 @@ int	fd;
 		syserr("dlunbindreq:  putmsg");
 }
 
+void
 dlokack(fd, bufp)
 int	fd;
 char	*bufp;
@@ -380,6 +398,7 @@ char	*bufp;
 		err("dlokack:  short response ctl.len:  %d", ctl.len);
 }
 
+void
 dlerrorack(fd, bufp)
 int	fd;
 char	*bufp;
@@ -408,6 +427,7 @@ char	*bufp;
 		err("dlerrorack:  short response ctl.len:  %d", ctl.len);
 }
 
+void
 dlbindack(fd, bufp)
 int	fd;
 char	*bufp;
@@ -433,6 +453,7 @@ char	*bufp;
 		err("dlbindack:  short response ctl.len:  %d", ctl.len);
 }
 
+void
 dlphysaddrack(fd, bufp)
 int	fd;
 char	*bufp;
@@ -695,10 +716,11 @@ union	DL_primitives	*dlp;
 printdlerrorack(dlp)
 union	DL_primitives	*dlp;
 {
-	(void) printf("DL_ERROR_ACK:  error_primitive %s errno %s unix_errno %d\n",
+	(void) printf("DL_ERROR_ACK:  error_primitive %s errno %s unix_errno %d: %s\n",
 		dlprim(dlp->error_ack.dl_error_primitive),
 		dlerrno(dlp->error_ack.dl_errno),
-		dlp->error_ack.dl_unix_errno);
+		dlp->error_ack.dl_unix_errno,
+		strerror(dlp->error_ack.dl_unix_errno));
 }
 
 printdlenabmultireq(dlp)
