@@ -416,10 +416,10 @@ u_short *portp;
 		*port++ = '\0';
 
 #ifdef	HAVE_INET_ATON
-	if (isdigit(*host) && inet_aton(host, &ip))
+	if (ISDIGIT(*host) && inet_aton(host, &ip))
 		*ipp = ip.s_addr;
 #else
-	if (isdigit(*host))
+	if (ISDIGIT(*host))
 		*ipp = inet_addr(host);
 #endif
 	else {
@@ -432,7 +432,7 @@ u_short *portp;
 	}
 
 	if (port) {
-		if (isdigit(*port))
+		if (ISDIGIT(*port))
 			*portp = htons(atoi(port));
 		else {
 			sp = getservbyname(port, "tcp");
@@ -525,7 +525,7 @@ char *filename;
 		/*
 		 * Skip leading whitespace
 		 */
-		for (line = buf; (c = *line) && isspace(c); line++)
+		for (line = buf; (c = *line) && ISSPACE(c); line++)
 			;
 		if (!*line)
 			continue;
